package api

import (
	"fmt"

	"github.com/gin-gonic/gin"
)

// RegRouters 注册路由
func RegRouters(svc *Service) {

	moutai := svc.NewGinRouter("/" + svc.Conf.Name)
	moutai.group.Use(Logger())

	// 获取token
	moutai.GET("/getToken", getToken)

	// 分类管理
	moutai.POSTJWT("/admin/cate/create", CategoryCreate)
	moutai.POSTJWT("/admin/cate/delete/:id", DeleteCategory)

	moutai.GET("/admin/cate/list", CategoryList)
	moutai.POSTJWT("/admin/cate/update", UpdateCategory)

	// 首页内容
	moutai.POSTJWT("/admin/home/content", HomeContent)
	moutai.GET("/admin/home/content", HomeDetail)

	// 图片管理
	moutai.POSTJWT("/admin/image/create", CreateImage)
	moutai.POSTJWT("/admin/image/delete/:id", DeleteImage)
	moutai.GET("/admin/image/list", ImageList)
	moutai.POSTJWT("/admin/image/update", UpdateImage)
	// 上架
	moutai.POSTJWT("/admin/image/on/:id", ImageOn)
	// 下架
	moutai.POSTJWT("/admin/image/off/:id", ImageOff)

	// 视频管理
	moutai.POSTJWT("/admin/video/create", CreateVideo)
	moutai.POSTJWT("/admin/video/delete/:id", DeleteVideo)
	moutai.GET("/admin/video/list", VideoList)
	moutai.POSTJWT("/admin/video/update", UpdateVideo)
	// 上架
	moutai.POSTJWT("/admin/video/on/:id", VideoOn)
	// 下架
	moutai.POSTJWT("/admin/video/off/:id", VideoOff)

	// 3d文物管理
	moutai.POSTJWT("/admin/relic/create", CreateRelic)
	moutai.POSTJWT("/admin/relic/delete/:id", DeleteRelic)
	moutai.GET("/admin/relic/list", RelicList)
	moutai.POSTJWT("/admin/relic/update", UpdateRelic)
	// 上架
	moutai.POSTJWT("/admin/relic/on/:id", RelicOn)
	// 下架
	moutai.POSTJWT("/admin/relic/off/:id", RelicOff)

	// vr管理
	moutai.POSTJWT("/admin/vr/create", CreateVr)
	moutai.POSTJWT("/admin/vr/delete/:id", DeleteVr)
	moutai.GET("/admin/vr/list", VrList)
	moutai.POSTJWT("/admin/vr/update", UpdateVr)
	// 上架
	moutai.POSTJWT("/admin/vr/on/:id", VrOn)
	// 下架
	moutai.POSTJWT("/admin/vr/off/:id", VrOff)

	// ar管理
	moutai.POSTJWT("/admin/ar/create", CreateAr)
	moutai.POSTJWT("/admin/ar/delete/:id", DeleteAr)
	moutai.GET("/admin/ar/list", ArList)
	moutai.POSTJWT("/admin/ar/update", UpdateAr)
	// 上架
	moutai.POSTJWT("/admin/ar/on/:id", ArOn)
	// 下架
	moutai.POSTJWT("/admin/ar/off/:id", ArOff)

	// 排序操作
	moutai.GET("/click", Clicks)
	moutai.GETJWT("/sort/top", SortTop)
	moutai.GETJWT("/sort/prev", SortPrev)
	moutai.GETJWT("/sort/next", SortNext)

}

func Logger() gin.HandlerFunc {

	return func(c *gin.Context) {
		// 开始时间
		// start := time.Now()
		// 处理请求
		c.Next()
		// 结束时间
		// end := time.Now()
		//执行时间
		// latency := end.Sub(start)

		path := c.Request.URL.Path

		clientIP := c.ClientIP()
		// method := c.Request.Method
		// statusCode := c.Writer.Status()

		out := fmt.Sprintf("%15s=> %s", clientIP, path)
		fmt.Println(out)
	}
}
